@@ -1,7 +1,7 @@
 package Archive::Merged;
 use strict;
 use Carp qw(croak);
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -137,8 +137,8 @@ sub extract_file {
 
 =head1 REPOSITORY
 
-The public repository of this module is 
-L<http://github.com/Corion/archive-merged>.
+The public repository of this module is
+L<https://github.com/Corion/archive-merged>.
 
 =head1 SUPPORT
 
@@ -157,7 +157,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2015-2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2015-2023 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
@@ -171,4 +171,4 @@ L<Archive::Tar>
 
 L<Archive::SevenZip::API::ArchiveTar>
 
-=cut
\ No newline at end of file
+=cut
